@@ -3,6 +3,8 @@ package Makefile::AST::Evaluator;
 use strict;
 use warnings;
 
+our $VERSION = '0.209';
+
 #use Smart::Comments;
 #use Smart::Comments '####';
 use File::stat;
@@ -11,7 +13,8 @@ use Class::Trigger qw(firing_rule);
 # XXX put these globals to some better place
 our (
     $Quiet, $JustPrint, $IgnoreErrors,
-    $AlwaysMake, $Question);
+    $AlwaysMake, $Question
+);
 
 sub new ($$) {
     my $class = ref $_[0] ? ref shift : shift;
